Databases Update
================

.. figure:: icons/databases-update.png

Updates local systems biology databases, like gene ontologies,
annotations, gene names, protein interaction networks, and similar.

Signals
-------

**Inputs**:

- None

**Outputs**:

- None

Description
-----------

With the bioinformatics add-on you can access several databases
directly from Orange. The widget can also be used to update and
manage locally stored databases.

.. figure:: images/database_update/DatabasesUpdate-stamped.png

1. Find the desired database.
2. A list of available databases described with data source, update availability, date of your last update and file size. 
   A large **Update** button will be displayed next to the database that needs to be updated.
3. **Update All** will update and **Download All** will download all the selected databases.
   **Cancel** will abort the action.
4. Some data sets require the *Access code*. Type it in the provided field to access the database.
5. Information on the selected databases.

To get a more detailed information on the particular database hover on its name.

.. figure:: images/database_update/DatabasesUpdate2.png
